/*
 * ----------------------------------------------------------------------------
 *  (C) Copyright Testing Technologies, 2001-2005.  All Rights Reserved.
 *
 *  All copies of this program, whether in whole or in part, and whether
 *  modified or not, must display this and all other embedded copyright
 *  and ownership notices in full.
 *
 *  See the file COPYRIGHT for details of redistribution and use.
 *
 *  You should have received a copy of the COPYRIGHT file along with
 *  this file; if not, write to the Testing Technologies,
 *  Rosenthaler Str. 13, 10119 Berlin, Germany.
 *
 *  TESTING TECHNOLOGIES DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS
 *  SOFTWARE. IN NO EVENT SHALL TESTING TECHNOLOGIES BE LIABLE FOR ANY
 *  SPECIAL, DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 *  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
 *  AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
 *  ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF
 *  THIS SOFTWARE.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND,
 *  EITHER EXPRESSED OR IMPLIED, INCLUDING ANY KIND OF IMPLIED OR
 *  EXPRESSED WARRANTY OF NON-INFRINGEMENT OR THE IMPLIED WARRANTIES
 *  OF MECHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 *
 * -----------------------------------------------------------------------------
 *
 *  AUTHOR:      ldte
 *  DATE:        Mar 14, 2005
 *
 *  REVISION INFO:
 *    $Revision: 1.3 $ $Date: 2005/06/22 14:44:34 $
 *    $Source: /net/ttech/cvs_root/IPv6_ETSI_STF276/javasrc/com/testingtech/ttcn/tri/RoutingEntry.java,v $
 *
 * -----------------------------------------------------------------------------
 */


package com.testingtech.ttcn.tri;

import java.math.BigInteger;

import org.etsi.ttcn.tri.TriComponentId;

import com.testingtech.util.HexViewer;

/**
 * The class to build the key for the send hashmap.
 * The key consists of the IPv6 address and the componentId.
 * 
 * @author dte
 *
 */
public class RoutingEntry {
    
    private byte [] ipv6Address = null;
    private TriComponentId componentId = null; 
    
    /**
     * The constructor of the class
     * 
     * @param ipv6Address	The IPv6 address
     * @param componentId	The component
     */
    public RoutingEntry(byte[] ipv6Address, TriComponentId componentId) {
        super();
        this.ipv6Address = ipv6Address;
        this.componentId = componentId;
    }

    
	/* (non-Javadoc)
	 * @see java.lang.Object#hashCode()
	 */
	public int hashCode() {
		return new BigInteger(this.ipv6Address).hashCode() + this.componentId.hashCode();
	}
	
	/* (non-Javadoc)
	 * @see java.lang.Object#equals(java.lang.Object)
	 */
	public boolean equals(Object re) {
		return ((new BigInteger(this.ipv6Address).equals(new BigInteger(((RoutingEntry)re).ipv6Address))) && (this.componentId.equals(((RoutingEntry)re).componentId)));
	}
	
    /**
     * @return Returns the ipv6Address.
     */
    public byte[] getIpv6Address() {
        return ipv6Address;
    }
    
    /**
     * @param ipv6Address The ipv6Address to set.
     */
    public void setIpv6Address(byte[] ipv6Address) {
        this.ipv6Address = ipv6Address;
    }
    
    /**
     * @return Returns the componentId.
     */
    public TriComponentId getComponentId() {
        return componentId;
    }
    
    /**
     * @param componentId The componentId to set.
     */
    public void setComponentId(TriComponentId componentId) {
        this.componentId = componentId;
    }
    
	/**
	 * Returns a string in the format "ipv6Address: " + the hex representation of the IPv6 address, "componentId: " and the component.
	 */
    public String toString() {
    	return "ipv6Address: " + HexViewer.hexString(ipv6Address) + ", componentId: " + componentId.getComponentId() + "\n";
    }
}
